@@ -7,7 +7,7 @@ from typing import Optional
 import boto3
 import validators
 from botocore.config import Config as BotoConfig
-from botocore.exceptions import ClientError, WaiterError
+from botocore.exceptions import ClientError, ConnectionError, WaiterError
 
 from ..decorators import retry
 from ..errors import (
@@ -15,9 +15,10 @@ from ..errors import (
     CliError,
     ErrorPatterns,
     InstanceNotFound,
+    OfflineError,
     raise_if_match,
 )
-from .config import SymConfigFile
+from .config import Config, SymConfigFile
 from .params import get_ssh_user
 
 InstanceIDPattern = re.compile("^i-[a-f0-9]+$")
@@ -30,6 +31,8 @@ def intercept_boto_errors(f):
     def wrapped(*args, **kwargs):
         try:
             return f(*args, **kwargs)
+        except ConnectionError as err:
+            raise OfflineError() from err
         except ClientError as err:
             if UnauthorizedError.search(str(err)):
                 raise BotoError(
@@ -50,10 +53,10 @@ def boto_client(saml_client, service):
     creds = saml_client.get_creds()
     return boto3.client(
         service,
-        config=BotoConfig(region_name=creds["AWS_REGION"]),
+        config=BotoConfig(region_name=creds.get("AWS_REGION")),
         aws_access_key_id=creds["AWS_ACCESS_KEY_ID"],
         aws_secret_access_key=creds["AWS_SECRET_ACCESS_KEY"],
-        aws_session_token=creds["AWS_SESSION_TOKEN"],
+        aws_session_token=creds.get("AWS_SESSION_TOKEN"),
     )
 
 
@@ -101,6 +104,9 @@ def _wait_for_command(ssm_client, instance, response):
 
 @intercept_boto_errors
 def find_instance(saml_client, keys, value) -> Optional[str]:
+    if (cached := Config.find_instance_by_alias(value)) :
+        return cached
+
     ec2_client = boto_client(saml_client, "ec2")
     for key in keys:
         paginator = ec2_client.get_paginator("describe_instances")
@@ -111,7 +117,9 @@ def find_instance(saml_client, keys, value) -> Optional[str]:
             ],
         ):
             if response["Reservations"]:
-                return response["Reservations"][0]["Instances"][0]["InstanceId"]
+                instance = response["Reservations"][0]["Instances"][0]["InstanceId"]
+                Config.add_instance_alias(instance, value)
+                return instance
 
 
 @intercept_boto_errors
