@@ -1,5 +1,6 @@
 import os
 import re
+import shlex
 import sys
 from datetime import timedelta
 from pathlib import Path
@@ -19,9 +20,10 @@ from ..errors import (
 )
 from ..helpers.boto import send_ssh_key
 from ..helpers.config import Config, SymConfigFile
+from ..helpers.contexts import push_envs
+from ..helpers.keywords_to_options import keywords_to_options
 from ..helpers.params import get_ssh_user
 from ..helpers.sym_group import SymGroup
-from ..helpers.tee import Tee
 
 MissingPublicKeyPattern = re.compile(r"Permission denied \(.*publickey.*\)")
 TargetNotConnectedPattern = re.compile("TargetNotConnected")
@@ -33,7 +35,7 @@ SSHKeyPath = "ssh/key"
 
 
 def ssh_key_and_config(client: "SAMLClient"):
-    ssh_key = SymConfigFile(file_name=SSHKeyPath)
+    ssh_key = SymConfigFile(file_name=SSHKeyPath, uid_scope=False)
     ssh_config = client.subconfig(SSHConfigPath, ssh_key=str(ssh_key))
     return (ssh_key, ssh_config)
 
@@ -54,14 +56,18 @@ def gen_ssh_key(dest: SymConfigFile):
             raise
 
 
+def maybe_gen_ssh_key(client):
+    ssh_key, _ = ssh_key_and_config(client)
+    if not ssh_key.path.exists():
+        gen_ssh_key(ssh_key)
+
+
 def ssh_args(client, instance, port) -> tuple:
     _, ssh_config = ssh_key_and_config(client)
     opts = {
         "p": str(port),
         "F": str(ssh_config),
         "l": get_ssh_user(),
-        "v": client.debug,
-        "E": str(Tee.path_for_fd(client.log_dir, "ssh")) if client.log_dir else None,
     }
     return ("ssh", instance, opts)
 
@@ -156,8 +162,7 @@ def ensure_ssh_key(
     ))
     # fmt: on
 
-    if not ssh_key.path.exists():
-        gen_ssh_key(ssh_key)
+    maybe_gen_ssh_key(client)
 
     if Config.check_instance_ttl(instance, ttl):
         client.dprint(f"Skipping remote SSH key check for {instance}")
@@ -178,24 +183,20 @@ def ensure_ssh_key(
 
 def start_tunnel(client, instance: str, port: int):
     SymGroup.reset_tees()
+    with push_envs(client.get_creds()):
+        os.execvp(
+            "aws",
+            keywords_to_options(
+                [
+                    "aws",
+                    "ssm",
+                    "start-session",
+                    {
+                        "target": instance,
+                        "document_name": "AWS-StartSSHSession",
+                        "parameters": f"portNumber={port}",
+                    },
+                ]
+            ),
+        )
 
-    def handler(signum, frame):
-        devnull = os.open(os.devnull, os.O_WRONLY)
-        os.dup2(devnull, sys.stdout.fileno())
-        # Set error state on session end.
-        # If the connection was actually successful,
-        # the parent thread will re-set a success state.
-        # This is the only reliable way to avoid error
-        # loops with Ansible due to missing SSH public keys.
-        Config.touch_instance(instance, error=True)
-
-    signal(SIGPIPE, handler)
-
-    client.exec(
-        "aws",
-        "ssm",
-        "start-session",
-        target=instance,
-        document_name="AWS-StartSSHSession",
-        parameters=f"portNumber={port}",
-    )
