@@ -26,19 +26,19 @@ ErrorPatterns = {
 
 
 class AwsOkta(SAMLClient):
-    __slots__ = ["config_file", "resource", "debug", "_config"]
+    __slots__ = ["config_file", "resource", "options", "_config"]
     binary = "aws-okta"
     option_value = "aws-okta"
     priority = 5
     setup_help = "Run `aws-okta add`."
 
     resource: str
-    debug: bool
+    options: "GlobalOptions"
     config_file: Final[SymConfigFile]
     _config: Optional[ConfigParser]
 
-    def __init__(self, resource: str, *, debug: bool) -> None:
-        super().__init__(resource, debug=debug)
+    def __init__(self, resource: str, *, options: "GlobalOptions") -> None:
+        super().__init__(resource, options=options)
         self.config_file = SymConfigFile(resource=resource, file_name="aws-okta.cfg")
 
     def is_setup(self) -> bool:
@@ -74,17 +74,21 @@ class AwsOkta(SAMLClient):
                 },
             )
 
-    def _ensure_session(self):
+    def _ensure_session(self, *, force: bool):
         # aws-okta fails in mysterious ways if your
         # keychain credentials are deleted after setup.
         # This logic handles that case cleanly.
         try:
-            super()._ensure_session()
+            super()._ensure_session(force=force)
         except FailedSubprocessError:
-            print("Logging in to Okta...", file=sys.stderr)
-            self._login(silence_stderr_=False)
-            print("Fetching SAML assertion...", file=sys.stderr)
-            super()._ensure_session()
+            pass
+        else:
+            if not force:
+                return
+        print("Logging in to Okta...", file=sys.stderr)
+        self._login(silence_stderr_=False)
+        print("Fetching SAML assertion...", file=sys.stderr)
+        super()._ensure_session(force=force)
 
     @property
     def okta_domain(self) -> str:
