@@ -166,10 +166,12 @@ class SAMLClient(ABC):
             )
         }
 
-    def _creds_expiring(self, buffer=timedelta(minutes=15)):
+    def _creds_expiring(self, buffer=timedelta(minutes=10)):
         if (expires := self.get_creds().get("AWS_CREDENTIAL_EXPIRATION")) :
             parsed = datetime.fromisoformat(expires)
-            return datetime.now(parsed.tzinfo) + buffer < parsed
+            remaining = parsed - datetime.now(parsed.tzinfo)
+            self.dprint(f"{remaining} remaining in creds session")
+            return remaining < buffer
         return False
 
     def write_creds(self, *, path: Path, profile: str):
